diff --git a/dumux/implicit/1p/1pmodel.hh b/dumux/implicit/1p/1pmodel.hh
index 009b292da1717ebde4909a66df43ce743d7ec684..612f88da48f22c99b239b9898488fab0521ada9b 100644
--- a/dumux/implicit/1p/1pmodel.hh
+++ b/dumux/implicit/1p/1pmodel.hh
@@ -121,12 +121,12 @@ public:
 
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->dofMapper().map(*eIt, scvIdx, dofCodim);
+                    int dofIdxGlobal = this->dofMapper().map(*eIt, scvIdx, dofCodim);
 
                     const SpatialParams &spatialParams = this->problem_().spatialParams();
 
-                    (*p)[globalIdx] = elemVolVars[scvIdx].pressure();
-                    (*K)[globalIdx] = spatialParams.intrinsicPermeability(*eIt,
+                    (*p)[dofIdxGlobal] = elemVolVars[scvIdx].pressure();
+                    (*K)[dofIdxGlobal] = spatialParams.intrinsicPermeability(*eIt,
                                                                          fvGeometry,
                                                                          scvIdx);
                 }
diff --git a/dumux/implicit/1p2c/1p2cmodel.hh b/dumux/implicit/1p2c/1p2cmodel.hh
index 4abe9faedfd1c50fe6576c44014c34f3db46e2bc..5bc34063eb6f3c0df87d7c787f81e60912f70a01 100644
--- a/dumux/implicit/1p2c/1p2cmodel.hh
+++ b/dumux/implicit/1p2c/1p2cmodel.hh
@@ -151,16 +151,16 @@ public:
 
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->dofMapper().map(*eIt, scvIdx, dofCodim);
-
-                    pressure[globalIdx] = elemVolVars[scvIdx].pressure();
-                    delp[globalIdx] = elemVolVars[scvIdx].pressure() - 1e5;
-                    moleFraction0[globalIdx] = elemVolVars[scvIdx].moleFraction(0);
-                    moleFraction1[globalIdx] = elemVolVars[scvIdx].moleFraction(1);
-                    massFraction0[globalIdx] = elemVolVars[scvIdx].massFraction(0);
-                    massFraction1[globalIdx] = elemVolVars[scvIdx].massFraction(1);
-                    rho[globalIdx] = elemVolVars[scvIdx].density();
-                    mu[globalIdx] = elemVolVars[scvIdx].viscosity();
+                    int dofIdxGlobal = this->dofMapper().map(*eIt, scvIdx, dofCodim);
+
+                    pressure[dofIdxGlobal] = elemVolVars[scvIdx].pressure();
+                    delp[dofIdxGlobal] = elemVolVars[scvIdx].pressure() - 1e5;
+                    moleFraction0[dofIdxGlobal] = elemVolVars[scvIdx].moleFraction(0);
+                    moleFraction1[dofIdxGlobal] = elemVolVars[scvIdx].moleFraction(1);
+                    massFraction0[dofIdxGlobal] = elemVolVars[scvIdx].massFraction(0);
+                    massFraction1[dofIdxGlobal] = elemVolVars[scvIdx].massFraction(1);
+                    rho[dofIdxGlobal] = elemVolVars[scvIdx].density();
+                    mu[dofIdxGlobal] = elemVolVars[scvIdx].viscosity();
                 }
 
                 // velocity output
diff --git a/dumux/implicit/2p/2pmodel.hh b/dumux/implicit/2p/2pmodel.hh
index ca3d004fa0335d7e5febc5f7d2e02c668d8ce077..b1e15141b5ba31345160a977a85dbe28545184eb 100644
--- a/dumux/implicit/2p/2pmodel.hh
+++ b/dumux/implicit/2p/2pmodel.hh
@@ -160,19 +160,19 @@ public:
 
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->dofMapper().map(*eIt, scvIdx, dofCodim);
-
-                    (*pw)[globalIdx] = elemVolVars[scvIdx].pressure(wPhaseIdx);
-                    (*pn)[globalIdx] = elemVolVars[scvIdx].pressure(nPhaseIdx);
-                    (*pc)[globalIdx] = elemVolVars[scvIdx].capillaryPressure();
-                    (*sw)[globalIdx] = elemVolVars[scvIdx].saturation(wPhaseIdx);
-                    (*sn)[globalIdx] = elemVolVars[scvIdx].saturation(nPhaseIdx);
-                    (*rhoW)[globalIdx] = elemVolVars[scvIdx].density(wPhaseIdx);
-                    (*rhoN)[globalIdx] = elemVolVars[scvIdx].density(nPhaseIdx);
-                    (*mobW)[globalIdx] = elemVolVars[scvIdx].mobility(wPhaseIdx);
-                    (*mobN)[globalIdx] = elemVolVars[scvIdx].mobility(nPhaseIdx);
-                    (*poro)[globalIdx] = elemVolVars[scvIdx].porosity();
-                    (*Te)[globalIdx] = elemVolVars[scvIdx].temperature();
+                    int dofIdxGlobal = this->dofMapper().map(*eIt, scvIdx, dofCodim);
+
+                    (*pw)[dofIdxGlobal] = elemVolVars[scvIdx].pressure(wPhaseIdx);
+                    (*pn)[dofIdxGlobal] = elemVolVars[scvIdx].pressure(nPhaseIdx);
+                    (*pc)[dofIdxGlobal] = elemVolVars[scvIdx].capillaryPressure();
+                    (*sw)[dofIdxGlobal] = elemVolVars[scvIdx].saturation(wPhaseIdx);
+                    (*sn)[dofIdxGlobal] = elemVolVars[scvIdx].saturation(nPhaseIdx);
+                    (*rhoW)[dofIdxGlobal] = elemVolVars[scvIdx].density(wPhaseIdx);
+                    (*rhoN)[dofIdxGlobal] = elemVolVars[scvIdx].density(nPhaseIdx);
+                    (*mobW)[dofIdxGlobal] = elemVolVars[scvIdx].mobility(wPhaseIdx);
+                    (*mobN)[dofIdxGlobal] = elemVolVars[scvIdx].mobility(nPhaseIdx);
+                    (*poro)[dofIdxGlobal] = elemVolVars[scvIdx].porosity();
+                    (*Te)[dofIdxGlobal] = elemVolVars[scvIdx].temperature();
                 }
 
                 // velocity output
diff --git a/dumux/implicit/2p2c/2p2cvolumevariables.hh b/dumux/implicit/2p2c/2p2cvolumevariables.hh
index f663d5134e4eff729f7edd573b2ad78f3aaacfaa..28d76eb9dd7d68ceb3925150a2dc7376e0b0b459 100644
--- a/dumux/implicit/2p2c/2p2cvolumevariables.hh
+++ b/dumux/implicit/2p2c/2p2cvolumevariables.hh
@@ -179,9 +179,9 @@ public:
                                                 fvGeometry, scvIdx);
         fluidState.setTemperature(t);
 
-        int globalIdx = problem.model().dofMapper().map(element, scvIdx, dofCodim);
+        int dofIdxGlobal = problem.model().dofMapper().map(element, scvIdx, dofCodim);
 
-        int phasePresence = problem.model().phasePresence(globalIdx, isOldSol);
+        int phasePresence = problem.model().phasePresence(dofIdxGlobal, isOldSol);
 
         /////////////
         // set the saturations
diff --git a/dumux/implicit/3p/3pmodel.hh b/dumux/implicit/3p/3pmodel.hh
index 18fa8c24910472c4de45ff7d6e2ede4f57ff350c..7a7b34c7e978c74817e7436369ebc2a018c0edc0 100644
--- a/dumux/implicit/3p/3pmodel.hh
+++ b/dumux/implicit/3p/3pmodel.hh
@@ -157,17 +157,17 @@ public:
 
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->dofMapper().map(*eIt, scvIdx, dofCodim);
+                    int dofIdxGlobal = this->dofMapper().map(*eIt, scvIdx, dofCodim);
 
                     for (int phaseIdx = 0; phaseIdx < numPhases; ++ phaseIdx) {
-                        (*saturation[phaseIdx])[globalIdx] = elemVolVars[scvIdx].saturation(phaseIdx);
-                        (*pressure[phaseIdx])[globalIdx] = elemVolVars[scvIdx].pressure(phaseIdx);
-                        (*density[phaseIdx])[globalIdx] = elemVolVars[scvIdx].density(phaseIdx);
+                        (*saturation[phaseIdx])[dofIdxGlobal] = elemVolVars[scvIdx].saturation(phaseIdx);
+                        (*pressure[phaseIdx])[dofIdxGlobal] = elemVolVars[scvIdx].pressure(phaseIdx);
+                        (*density[phaseIdx])[dofIdxGlobal] = elemVolVars[scvIdx].density(phaseIdx);
                     }
 
-                    (*poro)[globalIdx] = elemVolVars[scvIdx].porosity();
-                    (*perm)[globalIdx] = elemVolVars[scvIdx].permeability();
-                    (*temperature)[globalIdx] = elemVolVars[scvIdx].temperature();
+                    (*poro)[dofIdxGlobal] = elemVolVars[scvIdx].porosity();
+                    (*perm)[dofIdxGlobal] = elemVolVars[scvIdx].permeability();
+                    (*temperature)[dofIdxGlobal] = elemVolVars[scvIdx].temperature();
                 }
 
                 // velocity output
diff --git a/dumux/implicit/3p3c/3p3cvolumevariables.hh b/dumux/implicit/3p3c/3p3cvolumevariables.hh
index 48493daba1fda6771904e2161cb6c92d227d853b..af3dab715a9113fda650f76bbb61d9a56ad7d84a 100644
--- a/dumux/implicit/3p3c/3p3cvolumevariables.hh
+++ b/dumux/implicit/3p3c/3p3cvolumevariables.hh
@@ -125,9 +125,9 @@ public:
         const MaterialLawParams &materialParams =
             problem.spatialParams().materialLawParams(element, fvGeometry, scvIdx);
 
-        int globalIdx = problem.model().dofMapper().map(element, scvIdx, dofCodim);
+        int dofIdxGlobal = problem.model().dofMapper().map(element, scvIdx, dofCodim);
 
-        int phasePresence = problem.model().phasePresence(globalIdx, isOldSol);
+        int phasePresence = problem.model().phasePresence(dofIdxGlobal, isOldSol);
 
         Scalar temp = Implementation::temperature_(priVars, problem, element, fvGeometry, scvIdx);
         fluidState_.setTemperature(temp);
diff --git a/dumux/implicit/co2/co2model.hh b/dumux/implicit/co2/co2model.hh
index 5631089666e1e8d913fb777b4581dbe75efa48f8..7c107d97dda6d961f9b0c6890cacd265b5e30323 100644
--- a/dumux/implicit/co2/co2model.hh
+++ b/dumux/implicit/co2/co2model.hh
@@ -113,13 +113,13 @@ public:
              fvGeometry.update(this->gridView_(), *eIt);
              for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
              {
-                 int globalIdx = this->dofMapper().map(*eIt, scvIdx, dofCodim);
+                 int dofIdxGlobal = this->dofMapper().map(*eIt, scvIdx, dofCodim);
 
-                 if (ParentType::staticDat_[globalIdx].visited)
+                 if (ParentType::staticDat_[dofIdxGlobal].visited)
                      continue;
 
-                 ParentType::staticDat_[globalIdx].visited = true;
-                 volVars.update(curGlobalSol[globalIdx],
+                 ParentType::staticDat_[dofIdxGlobal].visited = true;
+                 volVars.update(curGlobalSol[dofIdxGlobal],
                                 this->problem_(),
                                 *eIt,
                                 fvGeometry,
@@ -128,10 +128,10 @@ public:
                  const GlobalPosition &globalPos = eIt->geometry().corner(scvIdx);
                  if (primaryVarSwitch_(curGlobalSol,
                                        volVars,
-                                       globalIdx,
+                                       dofIdxGlobal,
                                        globalPos))
                  {
-                     this->jacobianAssembler().markDofRed(globalIdx);
+                     this->jacobianAssembler().markDofRed(dofIdxGlobal);
                      wasSwitched = true;
                  }
              }
@@ -154,13 +154,13 @@ public:
       *        variable switch was performed.
       */
      bool primaryVarSwitch_(SolutionVector &globalSol,
-                              const VolumeVariables &volVars, int globalIdx,
+                              const VolumeVariables &volVars, int dofIdxGlobal,
                               const GlobalPosition &globalPos)
        {
          typename FluidSystem::ParameterCache paramCache;
            // evaluate primary variable switch
            bool wouldSwitch = false;
-           int phasePresence = ParentType::staticDat_[globalIdx].phasePresence;
+           int phasePresence = ParentType::staticDat_[dofIdxGlobal].phasePresence;
            int newPhasePresence = phasePresence;
 
            // check if a primary var switch is necessary
@@ -173,21 +173,21 @@ public:
                if(xnw > xnwMax)
                    wouldSwitch = true;
 
-               if (ParentType::staticDat_[globalIdx].wasSwitched)
+               if (ParentType::staticDat_[dofIdxGlobal].wasSwitched)
                    xnwMax *= 1.02;
 
                //If mole fraction is higher than the equilibrium mole fraction make a phase switch
                if(xnw > xnwMax)
                {
                    // wetting phase appears
-                   std::cout << "wetting phase appears at vertex " << globalIdx
+                   std::cout << "wetting phase appears at vertex " << dofIdxGlobal
                              << ", coordinates: " << globalPos << ", xnw > xnwMax: "
                              << xnw << " > "<< xnwMax << std::endl;
                    newPhasePresence = bothPhases;
                    if (formulation == pnsw)
-                       globalSol[globalIdx][switchIdx] = 0.0;
+                       globalSol[dofIdxGlobal][switchIdx] = 0.0;
                    else if (formulation == pwsn)
-                       globalSol[globalIdx][switchIdx] = 1.0;
+                       globalSol[dofIdxGlobal][switchIdx] = 1.0;
                }
            }
            else if (phasePresence == wPhaseOnly)
@@ -199,47 +199,47 @@ public:
                //If mole fraction is higher than the equilibrium mole fraction make a phase switch
                if(xwn > xwnMax)
                    wouldSwitch = true;
-               if (ParentType::staticDat_[globalIdx].wasSwitched)
+               if (ParentType::staticDat_[dofIdxGlobal].wasSwitched)
                    xwnMax *= 1.02;
 
 
                if(xwn > xwnMax)
                {
                    // non-wetting phase appears
-                   std::cout << "non-wetting phase appears at vertex " << globalIdx
+                   std::cout << "non-wetting phase appears at vertex " << dofIdxGlobal
                              << ", coordinates: " << globalPos << ", xwn > xwnMax: "
                              << xwn << " > "<< xwnMax << std::endl;
 
                    newPhasePresence = bothPhases;
                    if (formulation == pnsw)
-                       globalSol[globalIdx][switchIdx] = 0.999;
+                       globalSol[dofIdxGlobal][switchIdx] = 0.999;
                    else if (formulation == pwsn)
-                       globalSol[globalIdx][switchIdx] = 0.001;
+                       globalSol[dofIdxGlobal][switchIdx] = 0.001;
                }
            }
            else if (phasePresence == bothPhases)
            {
                Scalar Smin = 0.0;
-               if (ParentType::staticDat_[globalIdx].wasSwitched)
+               if (ParentType::staticDat_[dofIdxGlobal].wasSwitched)
                    Smin = -0.01;
 
                if (volVars.saturation(nPhaseIdx) <= Smin)
                {
                    wouldSwitch = true;
                    // nonwetting phase disappears
-                   std::cout << "Nonwetting phase disappears at vertex " << globalIdx
+                   std::cout << "Nonwetting phase disappears at vertex " << dofIdxGlobal
                              << ", coordinates: " << globalPos << ", sn: "
                              << volVars.saturation(nPhaseIdx) << std::endl;
                    newPhasePresence = wPhaseOnly;
 
                    if(!useMoles) //mass-fraction formulation
                    {
-					   globalSol[globalIdx][switchIdx]
+					   globalSol[dofIdxGlobal][switchIdx]
 						   = volVars.massFraction(wPhaseIdx, nCompIdx);
                    }
                    else //mole-fraction formulation
                    {
-					   globalSol[globalIdx][switchIdx]
+					   globalSol[dofIdxGlobal][switchIdx]
 					       = volVars.moleFraction(wPhaseIdx, nCompIdx);
                    }
                }
@@ -247,26 +247,26 @@ public:
                {
                    wouldSwitch = true;
                    // wetting phase disappears
-                   std::cout << "Wetting phase disappears at vertex " << globalIdx
+                   std::cout << "Wetting phase disappears at vertex " << dofIdxGlobal
                              << ", coordinates: " << globalPos << ", sw: "
                              << volVars.saturation(wPhaseIdx) << std::endl;
                    newPhasePresence = nPhaseOnly;
 
                    if(!useMoles) //mass-fraction formulation
                    {
-					   globalSol[globalIdx][switchIdx]
+					   globalSol[dofIdxGlobal][switchIdx]
 						   = volVars.massFraction(nPhaseIdx, wCompIdx);
                    }
                    else //mole-fraction formulation
                    {
-						globalSol[globalIdx][switchIdx]
+						globalSol[dofIdxGlobal][switchIdx]
 						= volVars.moleFraction(nPhaseIdx, wCompIdx);
                    }
                }
            }
 
-           ParentType::staticDat_[globalIdx].phasePresence = newPhasePresence;
-           ParentType::staticDat_[globalIdx].wasSwitched = wouldSwitch;
+           ParentType::staticDat_[dofIdxGlobal].phasePresence = newPhasePresence;
+           ParentType::staticDat_[dofIdxGlobal].wasSwitched = wouldSwitch;
            return phasePresence != newPhasePresence;
        }
 
diff --git a/dumux/implicit/co2/co2volumevariables.hh b/dumux/implicit/co2/co2volumevariables.hh
index c7d93fe4082b5748e8d7603081a8f54a56f22243..e67d8c1abf2c0919247b749d966566f60b00fae7 100644
--- a/dumux/implicit/co2/co2volumevariables.hh
+++ b/dumux/implicit/co2/co2volumevariables.hh
@@ -119,9 +119,9 @@ public:
                 scvIdx,
                 isOldSol);
 
-        int globalIdx = problem.model().dofMapper().map(element, scvIdx, dofCodim);
+        int dofIdxGlobal = problem.model().dofMapper().map(element, scvIdx, dofCodim);
 
-        int phasePresence = problem.model().phasePresence(globalIdx, isOldSol);
+        int phasePresence = problem.model().phasePresence(dofIdxGlobal, isOldSol);
 
          Scalar temp = Implementation::temperature_(priVars, problem, element, fvGeometry, scvIdx);
          ParentType::fluidState_.setTemperature(temp);
@@ -371,8 +371,8 @@ public:
           Valgrind::CheckDefined(ParentType::porosity_);
 //          if(phasePresence == bothPhases)
 //          {
-//              std::cout<<"globalIdx = "<<globalIdx<<std::endl;
-//              std::cout<<"scvIdx = "<<globalIdx<<std::endl;
+//              std::cout<<"dofIdxGlobal = "<<dofIdxGlobal<<std::endl;
+//              std::cout<<"scvIdx = "<<scvIdx<<std::endl;
 //              std::cout<<"sn = "<<ParentType::fluidState_.saturation(nPhaseIdx)<<std::endl;
 //              std::cout<<"sw = "<<ParentType::fluidState_.saturation(wPhaseIdx)<<std::endl;
 //              std::cout<<"mobilityN = "<<ParentType::mobility(nPhaseIdx)<<std::endl;
diff --git a/dumux/implicit/common/implicitlocaljacobian.hh b/dumux/implicit/common/implicitlocaljacobian.hh
index e0b2638000521f59e555318c379fb9215ebb45d8..4f9c6c395d0dd5e67ed959b4e250737890dd220d 100644
--- a/dumux/implicit/common/implicitlocaljacobian.hh
+++ b/dumux/implicit/common/implicitlocaljacobian.hh
@@ -398,21 +398,21 @@ protected:
                                 const int col,
                                 const int pvIdx)
     {
-        int globalIdx;
+        int dofIdxGlobal;
         FVElementGeometry neighborFVGeom;
         ElementPointer neighbor(element_());
         if (isBox)
         {
-            globalIdx = vertexMapper_().map(element_(), col, dim);
+            dofIdxGlobal = vertexMapper_().map(element_(), col, dim);
         }
         else
         {
             neighbor = fvElemGeom_.neighbors[col];
             neighborFVGeom.updateInner(*neighbor);
-            globalIdx = problemPtr_->elementMapper().map(*neighbor);
+            dofIdxGlobal = problemPtr_->elementMapper().map(*neighbor);
         }
 
-        PrimaryVariables priVars(model_().curSol()[globalIdx]);
+        PrimaryVariables priVars(model_().curSol()[dofIdxGlobal]);
         VolumeVariables origVolVars(curVolVars_[col]);
 
         curVolVars_[col].setEvalPoint(&origVolVars);
diff --git a/dumux/implicit/common/implicitvelocityoutput.hh b/dumux/implicit/common/implicitvelocityoutput.hh
index 6286fcefcba572a667131b872c816e1a30801bdf..7354736a6f4cd62a16711887189a00949e4bb4fc 100644
--- a/dumux/implicit/common/implicitvelocityoutput.hh
+++ b/dumux/implicit/common/implicitvelocityoutput.hh
@@ -98,9 +98,9 @@ public:
                 // transform vertex velocities from local to global coordinates
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = problem_.vertexMapper().map(*eIt, scvIdx, dofCodim);
+                    int vIdxGlobal = problem_.vertexMapper().map(*eIt, scvIdx, dofCodim);
 
-                    cellNum_[globalIdx] += 1;
+                    cellNum_[vIdxGlobal] += 1;
                 }
             }
         }
@@ -178,14 +178,14 @@ public:
                 // transform vertex velocities from local to global coordinates
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = problem_.vertexMapper().map(element, scvIdx, dofCodim);
+                    int vIdxGlobal = problem_.vertexMapper().map(element, scvIdx, dofCodim);
                     // calculate the subcontrolvolume velocity by the Piola transformation
                     Dune::FieldVector<CoordScalar, dim> scvVelocity(0);
 
                     jacobianT2.mtv(scvVelocities[scvIdx], scvVelocity);
-                    scvVelocity /= element.geometry().integrationElement(localPos)*cellNum_[globalIdx];
+                    scvVelocity /= element.geometry().integrationElement(localPos)*cellNum_[vIdxGlobal];
                     // add up the wetting phase subcontrolvolume velocities for each vertex
-                    velocity[globalIdx] += scvVelocity;
+                    velocity[vIdxGlobal] += scvVelocity;
                 }
             }
             else
@@ -234,9 +234,9 @@ public:
 
                 scvVelocity /= element.geometry().integrationElement(localPos);
 
-                int globalIdx = problem_.elementMapper().map(element);
+                int eIdxGlobal = problem_.elementMapper().map(element);
 
-                velocity[globalIdx]= scvVelocity;
+                velocity[eIdxGlobal]= scvVelocity;
             }
         } // velocity output
     }
diff --git a/dumux/implicit/mpnc/energy/mpncvtkwriterenergy.hh b/dumux/implicit/mpnc/energy/mpncvtkwriterenergy.hh
index c4c64d7399cc02188cc6fcea17bc0e7c8a895510..d9eb7938d2111befa52edaa38d65cc204696cb63 100644
--- a/dumux/implicit/mpnc/energy/mpncvtkwriterenergy.hh
+++ b/dumux/implicit/mpnc/energy/mpncvtkwriterenergy.hh
@@ -96,11 +96,11 @@ public:
                         const ElementBoundaryTypes &elemBcTypes)
     {
         for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx) {
-            const unsigned int globalIdx = this->problem_.model().dofMapper().map(element, scvIdx, dofCodim);
+            const unsigned int dofIdxGlobal = this->problem_.model().dofMapper().map(element, scvIdx, dofCodim);
             const VolumeVariables &volVars = elemVolVars[scvIdx];
 
             if (temperatureOutput_)
-                temperature_[globalIdx] = volVars.fluidState().temperature(/*phaseIdx=*/0);
+                temperature_[dofIdxGlobal] = volVars.fluidState().temperature(/*phaseIdx=*/0);
         }
     }
 
diff --git a/dumux/implicit/mpnc/mass/mpncvtkwritermass.hh b/dumux/implicit/mpnc/mass/mpncvtkwritermass.hh
index cfc28dbafbecf2962bf6cd2908a5c1cd78526919..7b7c66862628b828294b0a26bb52cff19d0926cb 100644
--- a/dumux/implicit/mpnc/mass/mpncvtkwritermass.hh
+++ b/dumux/implicit/mpnc/mass/mpncvtkwritermass.hh
@@ -94,12 +94,12 @@ public:
                         const ElementBoundaryTypes &elemBcTypes)
     {
         for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx) {
-            const unsigned int globalIdx = this->problem_.model().dofMapper().map(element, scvIdx, dofCodim);
+            const unsigned int dofIdxGlobal = this->problem_.model().dofMapper().map(element, scvIdx, dofCodim);
             const VolumeVariables &volVars = elemVolVars[scvIdx];
 
             if (fugacityOutput_) {
                 for (int compIdx = 0; compIdx < numComponents; ++compIdx) {
-                    fugacity_[compIdx][globalIdx] = volVars.fluidState().fugacity(compIdx);
+                    fugacity_[compIdx][dofIdxGlobal] = volVars.fluidState().fugacity(compIdx);
                 }
             }
         }
diff --git a/dumux/implicit/mpnc/mpncvtkwritercommon.hh b/dumux/implicit/mpnc/mpncvtkwritercommon.hh
index 249b7e210715d88be2f14f7b87b73135b029ac5a..b1820356d597879004ee87c1c79cd3f1a9329514 100644
--- a/dumux/implicit/mpnc/mpncvtkwritercommon.hh
+++ b/dumux/implicit/mpnc/mpncvtkwritercommon.hh
@@ -130,14 +130,14 @@ public:
     {
         for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
         {
-            int globalIdx = this->problem_.model().dofMapper().map(element, scvIdx, dofCodim);
+            int dofIdxGlobal = this->problem_.model().dofMapper().map(element, scvIdx, dofCodim);
 
             const VolumeVariables &volVars = elemVolVars[scvIdx];
 
-            if (porosityOutput_) porosity_[globalIdx] = volVars.porosity();
+            if (porosityOutput_) porosity_[dofIdxGlobal] = volVars.porosity();
 
             // works for scalar permeability in spatialparameters
-            if (permeabilityOutput_) permeability_[globalIdx] = this->problem_.spatialParams().intrinsicPermeability(element,fvGeometry,scvIdx);
+            if (permeabilityOutput_) permeability_[dofIdxGlobal] = this->problem_.spatialParams().intrinsicPermeability(element,fvGeometry,scvIdx);
 
             // calculate a single value for the boundary type: use one
             // bit for each equation and set it to 1 if the equation
@@ -147,18 +147,18 @@ public:
                 if (elemBcTypes[scvIdx].isDirichlet(eqIdx))
                     tmp += (1 << eqIdx);
             }
-            if (boundaryTypesOutput_) boundaryTypes_[globalIdx] = tmp;
+            if (boundaryTypesOutput_) boundaryTypes_[dofIdxGlobal] = tmp;
 
             for (int phaseIdx = 0; phaseIdx < numPhases; ++phaseIdx) {
-                if (saturationOutput_) saturation_[phaseIdx][globalIdx] = volVars.fluidState().saturation(phaseIdx);
-                if (pressureOutput_) pressure_[phaseIdx][globalIdx] = volVars.fluidState().pressure(phaseIdx);
-                if (densityOutput_) density_[phaseIdx][globalIdx] = volVars.fluidState().density(phaseIdx);
-                if (mobilityOutput_) mobility_[phaseIdx][globalIdx] = volVars.mobility(phaseIdx);
-                if (averageMolarMassOutput_) averageMolarMass_[phaseIdx][globalIdx] = volVars.fluidState().averageMolarMass(phaseIdx);
+                if (saturationOutput_) saturation_[phaseIdx][dofIdxGlobal] = volVars.fluidState().saturation(phaseIdx);
+                if (pressureOutput_) pressure_[phaseIdx][dofIdxGlobal] = volVars.fluidState().pressure(phaseIdx);
+                if (densityOutput_) density_[phaseIdx][dofIdxGlobal] = volVars.fluidState().density(phaseIdx);
+                if (mobilityOutput_) mobility_[phaseIdx][dofIdxGlobal] = volVars.mobility(phaseIdx);
+                if (averageMolarMassOutput_) averageMolarMass_[phaseIdx][dofIdxGlobal] = volVars.fluidState().averageMolarMass(phaseIdx);
                 for (int compIdx = 0; compIdx < numComponents; ++compIdx) {
-                    if (moleFracOutput_) moleFrac_[phaseIdx][compIdx][globalIdx] = volVars.fluidState().moleFraction(phaseIdx, compIdx);
-                    if (massFracOutput_) massFrac_[phaseIdx][compIdx][globalIdx] = volVars.fluidState().massFraction(phaseIdx, compIdx);
-                    if (molarityOutput_) molarity_[phaseIdx][compIdx][globalIdx] = volVars.fluidState().molarity(phaseIdx, compIdx);
+                    if (moleFracOutput_) moleFrac_[phaseIdx][compIdx][dofIdxGlobal] = volVars.fluidState().moleFraction(phaseIdx, compIdx);
+                    if (massFracOutput_) massFrac_[phaseIdx][compIdx][dofIdxGlobal] = volVars.fluidState().massFraction(phaseIdx, compIdx);
+                    if (molarityOutput_) molarity_[phaseIdx][compIdx][dofIdxGlobal] = volVars.fluidState().molarity(phaseIdx, compIdx);
                 }
             }
         }
diff --git a/dumux/implicit/nonisothermal/nimodel.hh b/dumux/implicit/nonisothermal/nimodel.hh
index 2b00821f26bde9adddbcc3cb8bb13c381b3ee776..18b99fa06f872321cee12b8a792d41204cd3d418 100644
--- a/dumux/implicit/nonisothermal/nimodel.hh
+++ b/dumux/implicit/nonisothermal/nimodel.hh
@@ -113,8 +113,8 @@ public:
 
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->dofMapper().map(*eIt, scvIdx, dofCodim);
-                    temperature[globalIdx] = elemVolVars[scvIdx].temperature();
+                    int dofIdxGlobal = this->dofMapper().map(*eIt, scvIdx, dofCodim);
+                    temperature[dofIdxGlobal] = elemVolVars[scvIdx].temperature();
                 }
             }
         }
diff --git a/dumux/implicit/richards/richardsmodel.hh b/dumux/implicit/richards/richardsmodel.hh
index a44836c5741c1b25fbc932e0a8c93914c4f1775e..ebd0148f3a687791a316a04e3f42cda88d6a114b 100644
--- a/dumux/implicit/richards/richardsmodel.hh
+++ b/dumux/implicit/richards/richardsmodel.hh
@@ -188,19 +188,19 @@ public:
 
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->dofMapper().map(*eIt, scvIdx, dofCodim);
-
-                    (*pw)[globalIdx] = elemVolVars[scvIdx].pressure(wPhaseIdx);
-                    (*pn)[globalIdx] = elemVolVars[scvIdx].pressure(nPhaseIdx);
-                    (*pc)[globalIdx] = elemVolVars[scvIdx].capillaryPressure();
-                    (*sw)[globalIdx] = elemVolVars[scvIdx].saturation(wPhaseIdx);
-                    (*sn)[globalIdx] = elemVolVars[scvIdx].saturation(nPhaseIdx);
-                    (*rhoW)[globalIdx] = elemVolVars[scvIdx].density(wPhaseIdx);
-                    (*rhoN)[globalIdx] = elemVolVars[scvIdx].density(nPhaseIdx);
-                    (*mobW)[globalIdx] = elemVolVars[scvIdx].mobility(wPhaseIdx);
-                    (*mobN)[globalIdx] = elemVolVars[scvIdx].mobility(nPhaseIdx);
-                    (*poro)[globalIdx] = elemVolVars[scvIdx].porosity();
-                    (*Te)[globalIdx] = elemVolVars[scvIdx].temperature();
+                    int dofIdxGlobal = this->dofMapper().map(*eIt, scvIdx, dofCodim);
+
+                    (*pw)[dofIdxGlobal] = elemVolVars[scvIdx].pressure(wPhaseIdx);
+                    (*pn)[dofIdxGlobal] = elemVolVars[scvIdx].pressure(nPhaseIdx);
+                    (*pc)[dofIdxGlobal] = elemVolVars[scvIdx].capillaryPressure();
+                    (*sw)[dofIdxGlobal] = elemVolVars[scvIdx].saturation(wPhaseIdx);
+                    (*sn)[dofIdxGlobal] = elemVolVars[scvIdx].saturation(nPhaseIdx);
+                    (*rhoW)[dofIdxGlobal] = elemVolVars[scvIdx].density(wPhaseIdx);
+                    (*rhoN)[dofIdxGlobal] = elemVolVars[scvIdx].density(nPhaseIdx);
+                    (*mobW)[dofIdxGlobal] = elemVolVars[scvIdx].mobility(wPhaseIdx);
+                    (*mobN)[dofIdxGlobal] = elemVolVars[scvIdx].mobility(nPhaseIdx);
+                    (*poro)[dofIdxGlobal] = elemVolVars[scvIdx].porosity();
+                    (*Te)[dofIdxGlobal] = elemVolVars[scvIdx].temperature();
                 }
 
                 // velocity output
diff --git a/dumux/implicit/richards/richardsnewtoncontroller.hh b/dumux/implicit/richards/richardsnewtoncontroller.hh
index ca761ee163689067f339d2c81c8e59a4873852e1..93b8ce448aae7bccb4a010d0627322b451fd0c0a 100644
--- a/dumux/implicit/richards/richardsnewtoncontroller.hh
+++ b/dumux/implicit/richards/richardsnewtoncontroller.hh
@@ -97,13 +97,13 @@ public:
                 fvGeometry.update(gridView, *eIt);
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->model_().dofMapper().map(*eIt, scvIdx, dofCodim);
+                    int dofIdxGlobal = this->model_().dofMapper().map(*eIt, scvIdx, dofCodim);
 
                     // calculate the old wetting phase saturation
                     const SpatialParams &spatialParams = this->problem_().spatialParams();
                     const MaterialLawParams &mp = spatialParams.materialLawParams(*eIt, fvGeometry, scvIdx);
                     Scalar pcMin = MaterialLaw::pc(mp, 1.0);
-                    Scalar pw = uLastIter[globalIdx][pwIdx];
+                    Scalar pw = uLastIter[dofIdxGlobal][pwIdx];
                     Scalar pn = std::max(this->problem_().referencePressure(*eIt, fvGeometry, scvIdx),
                                          pw + pcMin);
                     Scalar pcOld = pn - pw;
@@ -115,9 +115,9 @@ public:
                     Scalar pwMax = pn - MaterialLaw::pc(mp, SwOld + 0.2);
 
                     // clamp the result
-                    pw = uCurrentIter[globalIdx][pwIdx];
+                    pw = uCurrentIter[dofIdxGlobal][pwIdx];
                     pw = std::max(pwMin, std::min(pw, pwMax));
-                    uCurrentIter[globalIdx][pwIdx] = pw;
+                    uCurrentIter[dofIdxGlobal][pwIdx] = pw;
 
                 }
             }
diff --git a/dumux/linear/amgparallelhelpers.hh b/dumux/linear/amgparallelhelpers.hh
index 96ae4fece6b27847e2e5eda113556c2bc35815ad..16b861fba64b2b4d7cfeaa76152d8a2546c848fa 100644
--- a/dumux/linear/amgparallelhelpers.hh
+++ b/dumux/linear/amgparallelhelpers.hh
@@ -521,12 +521,12 @@ public:
             if (entityIt->partitionType() == Dune::BorderEntity)
             {
                 int localIdx = problem_.model().dofMapper().map(*entityIt);
-                IdType globalIdx = gridView.grid().globalIdSet().id(*entityIt);
+                IdType dofIdxGlobal = gridView.grid().globalIdSet().id(*entityIt);
 
-                std::pair<IdType,int> g2iPair(globalIdx, localIdx);
+                std::pair<IdType,int> g2iPair(dofIdxGlobal, localIdx);
                 gid2Index_.insert(g2iPair);
 
-                std::pair<int,IdType> i2gPair(localIdx, globalIdx);
+                std::pair<int,IdType> i2gPair(localIdx, dofIdxGlobal);
                 index2GID_.insert(i2gPair);
 
             }
diff --git a/test/implicit/1p2c/1p2cniconductionproblem.hh b/test/implicit/1p2c/1p2cniconductionproblem.hh
index 29d05762f10f854c31013b0c27ec81d625016d0d..c1a2597d9200bc24d40e7afe23b5e8b68fc6ad9d 100644
--- a/test/implicit/1p2c/1p2cniconductionproblem.hh
+++ b/test/implicit/1p2c/1p2cniconductionproblem.hh
@@ -222,13 +222,13 @@ public:
                 fvGeometry.update(this->gridView(), *eIt);
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
+                    int dofIdxGlobal = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
                     if (isBox)
                         globalPos = eIt->geometry().corner(scvIdx);
                     else
                         globalPos = eIt->geometry().center();
 
-                    (*temperatureExact)[globalIdx] = temperatureHigh_ + (initialPriVars[temperatureIdx] - temperatureHigh_)
+                    (*temperatureExact)[dofIdxGlobal] = temperatureHigh_ + (initialPriVars[temperatureIdx] - temperatureHigh_)
                                                      *std::erf(0.5*std::sqrt(globalPos[0]*globalPos[0]*storage/time/effectiveThermalConductivity));
                 }
             }
diff --git a/test/implicit/1p2c/1p2cniconvectionproblem.hh b/test/implicit/1p2c/1p2cniconvectionproblem.hh
index 481c66666d84dc4a2affd6b5a527cf43f63421b1..bd7ab33509ab2b50155bfe5d4a39077bca426d82 100644
--- a/test/implicit/1p2c/1p2cniconvectionproblem.hh
+++ b/test/implicit/1p2c/1p2cniconvectionproblem.hh
@@ -231,13 +231,13 @@ public:
                 fvGeometry.update(this->gridView(), *eIt);
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
+                    int dofIdxGlobal = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
                     if (isBox)
                         globalPos = eIt->geometry().corner(scvIdx);
                     else
                         globalPos = eIt->geometry().center();
 
-                    (*temperatureExact)[globalIdx] = globalPos[0] < retardedFrontVelocity*time ? temperatureHigh_ : temperatureLow_;
+                    (*temperatureExact)[dofIdxGlobal] = globalPos[0] < retardedFrontVelocity*time ? temperatureHigh_ : temperatureLow_;
                 }
             }
             this->resultWriter().attachDofData(*temperatureExact, "temperatureExact", isBox);
diff --git a/dumux/implicit/common/implicitassembler.hh b/dumux/implicit/common/implicitassembler.hh
index 7e7e27ac01d958f801fca276dccc9b237a36642b..4748ebe332615aa58bcb0463443bc8b07c765d06 100644
--- a/dumux/implicit/common/implicitassembler.hh
+++ b/dumux/implicit/common/implicitassembler.hh
@@ -294,17 +294,17 @@ public:
      * \brief Force to reassemble a given degree of freedom
      * next time the assemble() method is called.
      *
      * \param globalIdx The global index of the degree of freedom
      */
-    void markDofRed(const int globalIdx)
+    void markDofRed(const int dofIdxGlobal)
     {
         if (!enablePartialReassemble_())
             return;
 
         if (isBox)
-            vertexColor_[globalIdx] = Red;
+            vertexColor_[dofIdxGlobal] = Red;
         else 
-            elementColor_[globalIdx] = Red;
+            elementColor_[dofIdxGlobal] = Red;
     }
 
     /*!
@@ -333,8 +333,8 @@ public:
         if (!enablePartialReassemble_())
             return Red; // reassemble unconditionally!
 
-        int globalIdx = vertexMapper_().map(element, vIdx, dim);
-        return vertexColor_[globalIdx];
+        int vIdxGlobal = vertexMapper_().map(element, vIdx, dim);
+        return vertexColor_[vIdxGlobal];
     }
 
     /*!
@@ -359,8 +359,8 @@ public:
         if (!enablePartialReassemble_())
             return Red; // reassemble unconditionally!
 
-        int globalIdx = elementMapper_().map(element);
-        return elementColor_[globalIdx];
+        int eIdxGlobal = elementMapper_().map(element);
+        return elementColor_[eIdxGlobal];
     }
 
     /*!
@@ -294,17 +294,17 @@ public:
      * next time the assemble() method is called.
      *
-     * \param globalIdx The global index of the degree of freedom
+     * \param dofIdxGlobal The global index of the degree of freedom
      */
diff --git a/dumux/implicit/mpnc/mpncmodelkinetic.hh b/dumux/implicit/mpnc/mpncmodelkinetic.hh
index 7037ba267bfb3cdde2a3febc835feb8dd10a4889..72f1fb54bc7179f288a58878c8abc7f0c6eb4174 100644
--- a/dumux/implicit/mpnc/mpncmodelkinetic.hh
+++ b/dumux/implicit/mpnc/mpncmodelkinetic.hh
@@ -319,22 +319,22 @@ public:
      * \brief Access to the averaged (magnitude of) velocity for each vertex.
      *
      * \param phaseIdx The index of the fluid phase
      * \param globalIdx The global index of the degree of freedom
      *
      */
     const Scalar volumeDarcyMagVelocity(const unsigned int phaseIdx,
-                                        const unsigned int globalIdx) const
-    { return volumeDarcyMagVelocity_[phaseIdx][globalIdx]; }
+                                        const unsigned int dofIdxGlobal) const
+    { return volumeDarcyMagVelocity_[phaseIdx][dofIdxGlobal]; }
 
     /*!
      * \brief Access to the averaged velocity for each vertex.
      *
      * \param phaseIdx The index of the fluid phase
      * \param globalIdx The global index of the degree of freedom
      */
     const GlobalPosition volumeDarcyVelocity(const unsigned int phaseIdx,
-                                        const unsigned int globalIdx) const
-    { return volumeDarcyVelocity_[phaseIdx][globalIdx]; }
+                                        const unsigned int dofIdxGlobal) const
+    { return volumeDarcyVelocity_[phaseIdx][dofIdxGlobal]; }
 
 private:
     PhaseGlobalPositionField volumeDarcyVelocity_;
@@ -319,22 +319,22 @@ public:
      *
      * \param phaseIdx The index of the fluid phase
-     * \param globalIdx The global index of the degree of freedom
+     * \param dofIdxGlobal The global index of the degree of freedom
      *
      */
@@ -319,22 +319,22 @@ public:
      *
      * \param phaseIdx The index of the fluid phase
-     * \param globalIdx The global index of the degree of freedom
+     * \param dofIdxGlobal The global index of the degree of freedom
      */
     const GlobalPosition volumeDarcyVelocity(const unsigned int phaseIdx,
diff --git a/test/implicit/2p2c/injectionproblem.hh b/test/implicit/2p2c/injectionproblem.hh
index ccc669e320aac588d2a123da4d5db6852bb695e4..dfba62ea82ebefabd1eac4e42207e7643228c6a9 100644
--- a/test/implicit/2p2c/injectionproblem.hh
+++ b/test/implicit/2p2c/injectionproblem.hh
@@ -356,11 +356,11 @@ public:
      * \brief Returns the initial phase state for a control volume.
      *
      * \param vertex The vertex
      * \param globalIdx The global index of the vertex
      * \param globalPos The global position
      */
     int initialPhasePresence(const Vertex &vertex,
-                             int &globalIdx,
+                             int &vIdxGlobal,
                              const GlobalPosition &globalPos) const
     { return Indices::wPhaseOnly; }
 
@@ -356,11 +356,11 @@ public:
      *
      * \param vertex The vertex
-     * \param globalIdx The global index of the vertex
+     * \param vIdxGlobal The global index of the vertex
      * \param globalPos The global position
      */
diff --git a/test/implicit/2p2c/waterairproblem.hh b/test/implicit/2p2c/waterairproblem.hh
index 670b3719b1493c8438c66191c14b2ea3d9243921..d0c1569c103ec494f6979077a6c38a5d9c40b803 100644
--- a/test/implicit/2p2c/waterairproblem.hh
+++ b/test/implicit/2p2c/waterairproblem.hh
@@ -341,11 +341,11 @@ public:
      * \brief Return the initial phase state inside a control volume.
      *
      * \param vertex The vertex
      * \param globalIdx The index of the global vertex
      * \param globalPos The global position
      */
     int initialPhasePresence(const Vertex &vertex,
-                             int &globalIdx,
+                             int &vIdxGlobal,
                              const GlobalPosition &globalPos) const
     {
         return wPhaseOnly;
@@ -341,11 +341,11 @@ public:
      *
      * \param vertex The vertex
-     * \param globalIdx The index of the global vertex
+     * \param vIdxGlobal The global index of the vertex
      * \param globalPos The global position
      */
diff --git a/test/implicit/3p3c/columnxylolproblem.hh b/test/implicit/3p3c/columnxylolproblem.hh
index a614e4bdda110125c3b008f8a1149d7f5fa00ca5..2f81f45658fa58fe38253f898a19f5bb2247f414 100644
--- a/test/implicit/3p3c/columnxylolproblem.hh
+++ b/test/implicit/3p3c/columnxylolproblem.hh
@@ -281,11 +281,11 @@ public:
      * \brief Return the initial phase state inside a control volume.
      *
      * \param vertex The vertex
      * \param globalIdx The index of the global vertex
      * \param globalPos The global position
      */
     int initialPhasePresence(const Vertex &vertex,
-                             int &globalIdx,
+                             int &vIdxGlobal,
                              const GlobalPosition &globalPos) const
     {
         return threePhases;
@@ -315,8 +315,8 @@ public:
 
             for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
             {
-                int globalIdx = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
-                (*Kxx)[globalIdx] = this->spatialParams().intrinsicPermeability(*eIt, fvGeometry, scvIdx);
+                int dofIdxGlobal = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
+                (*Kxx)[dofIdxGlobal] = this->spatialParams().intrinsicPermeability(*eIt, fvGeometry, scvIdx);
             }
         }
 
@@ -281,11 +281,11 @@ public:
      *
      * \param vertex The vertex
-     * \param globalIdx The index of the global vertex
+     * \param vIdxGlobal The global index of the vertex
      * \param globalPos The global position
      */
diff --git a/test/implicit/3p3c/infiltrationproblem.hh b/test/implicit/3p3c/infiltrationproblem.hh
index 336c665c16f205b05f4ef4ea2f096b0166f3b0df..eb4f478ff14d72a22cd76d90465193f5feaafcc1 100644
--- a/test/implicit/3p3c/infiltrationproblem.hh
+++ b/test/implicit/3p3c/infiltrationproblem.hh
@@ -336,11 +336,11 @@ public:
      * \brief Return the initial phase state inside a control volume.
      *
      * \param vertex The vertex
      * \param globalIdx The index of the global vertex
      * \param globalPos The global position
      */
     int initialPhasePresence(const Vertex &vertex,
-                             int &globalIdx,
+                             int &vIdxGlobal,
                              const GlobalPosition &globalPos) const
     {
         // return threePhases;
@@ -371,8 +371,8 @@ public:
 
             for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
             {
-                int globalIdx = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
-                (*Kxx)[globalIdx] = this->spatialParams().intrinsicPermeability(*eIt, fvGeometry, scvIdx);
+                int dofIdxGlobal = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
+                (*Kxx)[dofIdxGlobal] = this->spatialParams().intrinsicPermeability(*eIt, fvGeometry, scvIdx);
             }
         }
 
@@ -336,11 +336,11 @@ public:
      *
      * \param vertex The vertex
-     * \param globalIdx The index of the global vertex
+     * \param vIdxGlobal The global index of the vertex
      * \param globalPos The global position
      */
diff --git a/test/implicit/3p3c/kuevetteproblem.hh b/test/implicit/3p3c/kuevetteproblem.hh
index f24e22fba1df3f40ebfbd9d7ef3d3a2dd7a7129c..e9dba62ac28b72c20f4738cb4cc24b9be0c886ca 100644
--- a/test/implicit/3p3c/kuevetteproblem.hh
+++ b/test/implicit/3p3c/kuevetteproblem.hh
@@ -299,11 +299,11 @@ public:
      * \brief Return the initial phase state inside a control volume.
      *
      * \param vertex The vertex
      * \param globalIdx The index of the global vertex
      * \param globalPos The global position
      */
     int initialPhasePresence(const Vertex &vertex,
-                             const int &globalIdx,
+                             const int &vIdxGlobal,
                              const GlobalPosition &globalPos) const
     {
         if((globalPos[0] >= 0.20) && (globalPos[0] <= 0.80) && (globalPos[1] >= 0.4) && (globalPos[1] <= 0.65))
@@ -337,8 +337,8 @@ public:
 
             for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
             {
-                int globalIdx = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
-                (*Kxx)[globalIdx] = this->spatialParams().intrinsicPermeability(*eIt, fvGeometry, scvIdx);
+                int dofIdxGlobal = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
+                (*Kxx)[dofIdxGlobal] = this->spatialParams().intrinsicPermeability(*eIt, fvGeometry, scvIdx);
             }
         }
 
@@ -299,11 +299,11 @@ public:
      *
      * \param vertex The vertex
-     * \param globalIdx The index of the global vertex
+     * \param vIdxGlobal The global index of the vertex
      * \param globalPos The global position
      */
diff --git a/test/implicit/co2/heterogeneousproblem.hh b/test/implicit/co2/heterogeneousproblem.hh
index 83721cab0fa5c90b1318d51d002e8ee1216525de..9fb447f7f1f94e2112e0fbcaeb2e8fd6aec1d757 100644
--- a/test/implicit/co2/heterogeneousproblem.hh
+++ b/test/implicit/co2/heterogeneousproblem.hh
@@ -307,14 +307,14 @@ public:
 
              for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
              {
-                 int globalIdx = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
-                 volVars.update(this->model().curSol()[globalIdx],
+                 int dofIdxGlobal = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
+                 volVars.update(this->model().curSol()[dofIdxGlobal],
                                 *this,
                                 *eIt,
                                 fvGeometry,
                                 scvIdx,
                                 false);
-                 (*boxVolume)[globalIdx] += fvGeometry.subContVol[scvIdx].volume;
+                 (*boxVolume)[dofIdxGlobal] += fvGeometry.subContVol[scvIdx].volume;
              }
              (*Kxx)[eIdx] = this->spatialParams().intrinsicPermeability(*eIt, fvGeometry, /*element data*/ 0);
              (*cellPorosity)[eIdx] = this->spatialParams().porosity(*eIt, fvGeometry, /*element data*/ 0);
@@ -476,11 +476,11 @@ public:
      * \brief Returns the initial phase state for a control volume.
      *
      * \param vertex The vertex
      * \param globalIdx The global index of the vertex
      * \param globalPos The global position
      */
     int initialPhasePresence(const Vertex &vertex,
-                             int &globalIdx,
+                             int &vIdxGlobal,
                              const GlobalPosition &globalPos) const
     { return Indices::wPhaseOnly; }
 
@@ -476,11 +476,11 @@ public:
      *
      * \param vertex The vertex
-     * \param globalIdx The global index of the vertex
+     * \param vIdxGlobal The global index of the vertex
      * \param globalPos The global position
      */
diff --git a/test/implicit/co2ni/heterogeneousproblemni.hh b/test/implicit/co2ni/heterogeneousproblemni.hh
index 7457ac0e14158d1060fce52dfc537b129b26aeff..e9fc1208fa90222ddb16b617f9146462f47df684 100644
--- a/test/implicit/co2ni/heterogeneousproblemni.hh
+++ b/test/implicit/co2ni/heterogeneousproblemni.hh
@@ -306,16 +306,16 @@ public:
 
                 for (int scvIdx = 0; scvIdx < fvGeometry.numScv; ++scvIdx)
                 {
-                    int globalIdx = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
-                    volVars.update(this->model().curSol()[globalIdx],
+                    int dofIdxGlobal = this->model().dofMapper().map(*eIt, scvIdx, dofCodim);
+                    volVars.update(this->model().curSol()[dofIdxGlobal],
                                    *this,
                                    *eIt,
                                    fvGeometry,
                                    scvIdx,
                                    false);
-                    (*boxVolume)[globalIdx] += fvGeometry.subContVol[scvIdx].volume;
-                    (*enthalpyW)[globalIdx] = volVars.enthalpy(lPhaseIdx);
-                    (*enthalpyN)[globalIdx] = volVars.enthalpy(gPhaseIdx);
+                    (*boxVolume)[dofIdxGlobal] += fvGeometry.subContVol[scvIdx].volume;
+                    (*enthalpyW)[dofIdxGlobal] = volVars.enthalpy(lPhaseIdx);
+                    (*enthalpyN)[dofIdxGlobal] = volVars.enthalpy(gPhaseIdx);
                 }
                 (*Kxx)[eIdx] = this->spatialParams().intrinsicPermeability(*eIt, fvGeometry, /*element data*/ 0);
                 (*cellPorosity)[eIdx] = this->spatialParams().porosity(*eIt, fvGeometry, /*element data*/ 0);
@@ -486,11 +486,11 @@ public:
      * \brief Returns the initial phase state for a control volume.
      *
      * \param vertex The vertex
      * \param globalIdx The global index of the vertex
      * \param globalPos The global position
      */
     int initialPhasePresence(const Vertex &vertex,
-                             int &globalIdx,
+                             int &vIdxGlobal,
                              const GlobalPosition &globalPos) const
     { return Indices::wPhaseOnly; }
@@ -486,11 +486,11 @@ public:
      *
      * \param vertex The vertex
-     * \param globalIdx The global index of the vertex
+     * \param vIdxGlobal The global index of the vertex
      * \param globalPos The global position
      */